@@ -3,7 +3,6 @@
 #   Cython Scanner
 #
 
-import sys
 import os
 import platform
 
@@ -11,10 +10,10 @@ import cython
 cython.declare(EncodedString=object, string_prefixes=object, raw_prefixes=object, IDENT=unicode,
                print_function=object)
 
-from Cython import Plex, Utils
+from Cython import Utils
 from Cython.Plex.Scanners import Scanner
 from Cython.Plex.Errors import UnrecognizedInput
-from Errors import CompileError, error
+from Errors import error
 from Lexicon import string_prefixes, raw_prefixes, make_lexicon, IDENT
 from Future import print_function
 
@@ -68,6 +67,9 @@ class CompileTimeScope(object):
     def declare(self, name, value):
         self.entries[name] = value
 
+    def update(self, other):
+        self.entries.update(other)
+
     def lookup_here(self, name):
         return self.entries[name]
 
@@ -287,14 +289,17 @@ class PyrexScanner(Scanner):
             self.compile_time_env = initial_compile_time_env()
             self.compile_time_eval = 1
             self.compile_time_expr = 0
+            if hasattr(context.options, 'compile_time_env') and \
+               context.options.compile_time_env is not None:
+                self.compile_time_env.update(context.options.compile_time_env)
         self.parse_comments = parse_comments
         self.source_encoding = source_encoding
         if filename.is_python_file():
             self.in_python_file = True
-            self.keywords = cython.set(py_reserved_words)
+            self.keywords = set(py_reserved_words)
         else:
             self.in_python_file = False
-            self.keywords = cython.set(pyx_reserved_words)
+            self.keywords = set(pyx_reserved_words)
         self.trace = trace_scanner
         self.indentation_stack = [0]
         self.indentation_char = None
